"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BaseExtractor = void 0;

var _reactNative = require("react-native");

var _utils = require("../../utils");

const PdfExtractor = _reactNative.Platform.select({
  android: _reactNative.NativeModules.PdfExtractor,
  ios: {}
});

class BaseExtractor {
  static async getUri() {
    return PdfExtractor.getUri();
  }

  static async isEncrypted() {
    return PdfExtractor.isEncrypted();
  }

  static async setUri(uri) {
    return PdfExtractor.setUri(uri);
  }

  static async getNumberOfPages(password) {
    return PdfExtractor.getNumberOfPages(password);
  }

  static async canIExtract() {
    return PdfExtractor.canIExtract();
  }

  static async getText(password) {
    const data = await PdfExtractor.getText(password);
    return [...new Set((data === null || data === void 0 ? void 0 : data.split('\n')) || [])];
  }

  static async getTextWithPattern(pattern, password) {
    const patterns = Array.isArray(pattern) ? pattern : [pattern];
    const data = await this.getText(password);
    const matches = patterns.map(regex => (0, _utils.Match)(regex, data));
    return [...new Set(matches)].flat();
  }

}

exports.BaseExtractor = BaseExtractor;
//# sourceMappingURL=Base.js.map