"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CommonExtractor = void 0;

var _reactNative = require("react-native");

var _Base = require("./Base");

class CommonExtractor {
  /**
   * Verifies if file exists based on URI gave
   * or got from intent provider (Android only)
   */
  static async file(data) {
    if (data.uri) {
      const path = await _Base.BaseExtractor.setUri(data.uri);
      if (path) return { ...data,
        uri: path
      };
      throw new Error(`Invalid uri: '${data.uri}'. Cannot find the file.`);
    } // From Intent (android only)


    if (_reactNative.Platform.OS === 'android') {
      const path = await _Base.BaseExtractor.getUri();
      if (path) return { ...data,
        uri: path
      };
    }

    throw new Error('Could not perfom extraction without URI.');
  }
  /**
   * Checks if params satisfies full specification
   * to proceed with data extraction
   */


  static async check(data) {
    const canIExtract = await _Base.BaseExtractor.canIExtract();
    if (canIExtract) return data;
    throw new Error('You cannot continue with extraction.');
  }
  /**
   * Checks if file is encrypted
   */


  static async encrypted(data) {
    const isEncrypted = await _Base.BaseExtractor.isEncrypted();
    return { ...data,
      isEncrypted
    };
  }
  /**
   * Counts the number of pages
   */


  static async pages(data) {
    const total = await _Base.BaseExtractor.getNumberOfPages(data.password);

    if (total > data.max) {
      throw new Error(`This file exceeds maximum size of ${data.max} pages.`);
    }

    return { ...data,
      pages: total
    };
  }
  /**
   * Applies matches
   */


  static async matches(data) {
    const text = !data.patterns ? await _Base.BaseExtractor.getText(data.password) : await _Base.BaseExtractor.getTextWithPattern(data.patterns, data.password);
    return { ...data,
      text
    };
  }

}

exports.CommonExtractor = CommonExtractor;
//# sourceMappingURL=Common.js.map