"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Extractor = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeModal = _interopRequireDefault(require("react-native-modal"));

var _chains = require("../../chains");

var _Styles = _interopRequireDefault(require("./Styles"));

var _Common = require("./Common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Extractor = /*#__PURE__*/(0, _react.memo)(_ref => {
  let {
    cancel = 'Cancel',
    fromIntent,
    onResult,
    submit = 'Open',
    patterns,
    placeholder = 'Password',
    title = 'This file is protected',
    uri,
    max = 10
  } = _ref;
  const [locker, setLocker] = (0, _react.useState)();
  const [value, setValue] = (0, _react.useState)();
  const [password, setPassword] = (0, _react.useState)();
  const [visibility, setVisibility] = (0, _react.useState)(false);
  /**
   * Close modal
   */

  const close = () => {
    setVisibility(false);
    onResult(null);
  };
  /**
   * Triggers callbacks when password changes
   */


  const changePassword = (0, _react.useCallback)(() => {
    setVisibility(false);

    if (value !== null && value !== void 0 && value.length) {
      setPassword(value);
    } else {
      onResult(null);
    }
  }, [value, onResult]);
  /**
   * Verifies if needs user interaction to provide password
   * and shows component if needed
   */

  const verify = (0, _react.useCallback)(async () => {
    const data = await new _chains.Chain([new _chains.ChainLink(_Common.CommonExtractor.file), new _chains.ChainLink(_Common.CommonExtractor.check), new _chains.ChainLink(_Common.CommonExtractor.encrypted)]).exec({
      uri,
      patterns
    });

    if (data.isEncrypted && !password) {
      setVisibility(true);
    }

    return data;
  }, [uri, patterns, password]);
  /**
   * Perform data extraction
   */

  const extract = (0, _react.useCallback)(async data => {
    const start = new Date().getTime();
    const result = await new _chains.Chain([new _chains.ChainLink(_Common.CommonExtractor.pages), new _chains.ChainLink(_Common.CommonExtractor.matches)]).exec({ ...data,
      password,
      max: max
    });
    const finish = new Date().getTime();
    return { ...result,
      duration: `${finish - start}ms`
    };
  }, [max, password]);
  /**
   * Call data extraction functions
   */

  const exec = (0, _react.useCallback)(async () => {
    try {
      const data = await verify();

      if (data !== null && data !== void 0 && data.isEncrypted && password || !(data !== null && data !== void 0 && data.isEncrypted)) {
        const result = await extract(data);
        onResult(result);
      }
    } catch (error) {
      console.warn(error);
      onResult(null);
    }
  }, [extract, onResult, password, verify]);
  /**
   * Verifies if can re-render component or runs data extraction
   */

  (0, _react.useEffect)(() => {
    const withoutPatterns = uri !== null && uri !== void 0 ? uri : fromIntent;
    const withPatterns = uri && patterns || fromIntent && patterns;
    const lock = `${uri}|${patterns}|${fromIntent}|${password}`;

    if (lock !== locker && Boolean(withPatterns || withoutPatterns)) {
      setLocker(lock);
      exec();
    }
  }, [exec, uri, patterns, fromIntent, locker, password]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeModal.default, {
    hideModalContentWhileAnimating: false,
    isVisible: visibility,
    onBackButtonPress: close,
    useNativeDriver: true
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _Styles.default.Container
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _Styles.default.Title
  }, title), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    onChangeText: setValue,
    placeholder: placeholder,
    secureTextEntry: true,
    underlineColorAndroid: "gray"
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _Styles.default.Row
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: _Styles.default.Button,
    onPress: close
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _Styles.default.Text
  }, cancel)), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: _Styles.default.Button,
    onPress: changePassword
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _Styles.default.Text
  }, submit)))));
});
exports.Extractor = Extractor;
//# sourceMappingURL=Extractor.js.map