import React, { memo, useCallback, useEffect, useState } from 'react';
import { Text, TextInput, TouchableOpacity, View } from 'react-native';
import Modal from 'react-native-modal';
import { Chain, ChainLink } from '../../chains';
import Styles from './Styles';
import { CommonExtractor } from './Common';
export const Extractor = /*#__PURE__*/memo(_ref => {
  let {
    cancel = 'Cancel',
    fromIntent,
    onResult,
    submit = 'Open',
    patterns,
    placeholder = 'Password',
    title = 'This file is protected',
    uri,
    max = 10
  } = _ref;
  const [locker, setLocker] = useState();
  const [value, setValue] = useState();
  const [password, setPassword] = useState();
  const [visibility, setVisibility] = useState(false);
  /**
   * Close modal
   */

  const close = () => {
    setVisibility(false);
    onResult(null);
  };
  /**
   * Triggers callbacks when password changes
   */


  const changePassword = useCallback(() => {
    setVisibility(false);

    if (value !== null && value !== void 0 && value.length) {
      setPassword(value);
    } else {
      onResult(null);
    }
  }, [value, onResult]);
  /**
   * Verifies if needs user interaction to provide password
   * and shows component if needed
   */

  const verify = useCallback(async () => {
    const data = await new Chain([new ChainLink(CommonExtractor.file), new ChainLink(CommonExtractor.check), new ChainLink(CommonExtractor.encrypted)]).exec({
      uri,
      patterns
    });

    if (data.isEncrypted && !password) {
      setVisibility(true);
    }

    return data;
  }, [uri, patterns, password]);
  /**
   * Perform data extraction
   */

  const extract = useCallback(async data => {
    const start = new Date().getTime();
    const result = await new Chain([new ChainLink(CommonExtractor.pages), new ChainLink(CommonExtractor.matches)]).exec({ ...data,
      password,
      max: max
    });
    const finish = new Date().getTime();
    return { ...result,
      duration: `${finish - start}ms`
    };
  }, [max, password]);
  /**
   * Call data extraction functions
   */

  const exec = useCallback(async () => {
    try {
      const data = await verify();

      if (data !== null && data !== void 0 && data.isEncrypted && password || !(data !== null && data !== void 0 && data.isEncrypted)) {
        const result = await extract(data);
        onResult(result);
      }
    } catch (error) {
      console.warn(error);
      onResult(null);
    }
  }, [extract, onResult, password, verify]);
  /**
   * Verifies if can re-render component or runs data extraction
   */

  useEffect(() => {
    const withoutPatterns = uri !== null && uri !== void 0 ? uri : fromIntent;
    const withPatterns = uri && patterns || fromIntent && patterns;
    const lock = `${uri}|${patterns}|${fromIntent}|${password}`;

    if (lock !== locker && Boolean(withPatterns || withoutPatterns)) {
      setLocker(lock);
      exec();
    }
  }, [exec, uri, patterns, fromIntent, locker, password]);
  return /*#__PURE__*/React.createElement(Modal, {
    hideModalContentWhileAnimating: false,
    isVisible: visibility,
    onBackButtonPress: close,
    useNativeDriver: true
  }, /*#__PURE__*/React.createElement(View, {
    style: Styles.Container
  }, /*#__PURE__*/React.createElement(Text, {
    style: Styles.Title
  }, title), /*#__PURE__*/React.createElement(TextInput, {
    onChangeText: setValue,
    placeholder: placeholder,
    secureTextEntry: true,
    underlineColorAndroid: "gray"
  }), /*#__PURE__*/React.createElement(View, {
    style: Styles.Row
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: Styles.Button,
    onPress: close
  }, /*#__PURE__*/React.createElement(Text, {
    style: Styles.Text
  }, cancel)), /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: Styles.Button,
    onPress: changePassword
  }, /*#__PURE__*/React.createElement(Text, {
    style: Styles.Text
  }, submit)))));
});
//# sourceMappingURL=Extractor.js.map